@@ -10,8 +10,9 @@ SimulateGMMData <- function(n = 1000, theta = rtheta(...), ...) {
   K <- sample(seq_len(theta$m), size = n, replace = TRUE, prob = theta$pie)
 
   if (length(unique(K)) != theta$m) {
-    warning(paste("Some components was not represented in sample.",
-                  "The mixture proportions may be too small to be sampled.",
+    warning(paste("Some components were not represented in the sample.",
+                  "The mixture proportions may be too small to be sampled",
+                  "with the given n.",
                   "Ignore this warning, try to resample, or change theta."))
   }
 
